package com.koutra.dist.proc.util;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.Reader;

import junit.framework.Assert;

public class Util extends Assert {
	public static void testStreamEquivalence(InputStream a, InputStream b) throws IOException {
		while (true) {
			int inputFileByte = a.read();
			int outputFileByte = b.read();
			assertTrue(inputFileByte == outputFileByte);
			if (inputFileByte == -1)
				break;
		}
	}
	
	public static void testReaderEquivalence(Reader a, Reader b) throws IOException {
		while (true) {
			int inputFileChar = a.read();
			int outputFileChar = b.read();
			assertTrue(inputFileChar == outputFileChar);
			if (inputFileChar == -1)
				break;
		}
	}
	
	private static int readUntilNewLine(InputStream is, OutputStream os) throws IOException {
		while (true) {
			int charRead = is.read();
			if (charRead == -1)
				return -1;
			os.write(charRead);
			if (charRead < 0)
				charRead = 256 + charRead;
			if (charRead == '\n')
				break;
		}
		
		return 0;
	}
	
	public static void testPDFEquivalence(InputStream a, InputStream b) throws IOException {
		// PDF files has pesky things like creation time stamps and therefore
		// byte by byte comparisons are not helpful at all...
		// Consume the input streams then break them at newline characters. Between each
		// newline character assume that you have a "line". Try to convert each line to
		// a string using UTF-8.
		// Any lines that start with:
		// /CreationDate
		// <rdf:li>
		// <xmp:CreateDate>
		// /ID [<
		// can have valid differences, so ignore them
		// Other lines are not allowed differences.
		while (true) {
			ByteArrayOutputStream inputFileCurrentLine = new ByteArrayOutputStream();
			ByteArrayOutputStream outputFileCurrentLine = new ByteArrayOutputStream();

			int shouldBreakInputFile = readUntilNewLine(a, inputFileCurrentLine);
			int shouldBreakOutputFile = readUntilNewLine(b, outputFileCurrentLine);
			
			assertTrue(shouldBreakInputFile == shouldBreakOutputFile);
			
			if (shouldBreakInputFile == -1)
				break;
			
			byte[] inputFileBytes = inputFileCurrentLine.toByteArray();
			byte[] outputFileBytes = outputFileCurrentLine.toByteArray();
			String inputFileLine = new String(inputFileBytes, "UTF-8");
			String outputFileLine = new String(outputFileBytes, "UTF-8");
			
			boolean skipCheck =
				(inputFileLine.startsWith("/CreationDate") &&
				outputFileLine.startsWith("/CreationDate")) ||
				(inputFileLine.startsWith("<rdf:li>") &&
				outputFileLine.startsWith("<rdf:li>")) ||
				(inputFileLine.startsWith("<xmp:CreateDate>") &&
				outputFileLine.startsWith("<xmp:CreateDate>")) ||
				(inputFileLine.startsWith("/ID [<") &&
				outputFileLine.startsWith("/ID [<"));
			
			if (!skipCheck) {
				assertTrue(inputFileBytes.length == outputFileBytes.length);
				for (int i = 0; i < inputFileBytes.length; i++)
					assertTrue(inputFileBytes[i] == outputFileBytes[i]);
			}
		}
	}
}
