/*******************************************************************************
 * Copyright (c) 2009 Pafsanias Ftakas.
 *
 * This file is part of DistProc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * DistProc is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Eclipse Public License v1.0 for more details.
 *
 * Contributors:
 *     Pafsanias Ftakas - initial API and implementation
 *******************************************************************************/
package com.koutra.dist.proc.cluster;

import java.util.concurrent.Future;

import org.jgroups.Address;
import org.jgroups.util.Streamable;

/**
 * Helper class. Instances of this class are stored in the cluster nodes internal
 * data structures and represent a single cluster runnable and its current state.
 * 
 * @author Pafsanias Ftakas
 */
class Entry {
	private TaskID taskID;
	private Streamable payload;
	private Address originator;
	private Future<?> future;
	
	/**
	 * Initializing constructor.
	 * @param payload the streamable object
	 * @param originator the address of the sender
	 * @param future the future for the computation
	 */
	public Entry(TaskID taskID, Streamable payload, Address originator, Future<?> future) {
		this.taskID = taskID;
		this.payload = payload;
		this.originator = originator;
		this.future = future;
	}
	
	public TaskID getTaskID() {
		return taskID;
	}

	/**
	 * Getter for the future.
	 * @return the future
	 */
	public Future<?> getFuture() {
		return future;
	}

	/**
	 * Setter for the future.
	 * @param future the new value for the future
	 */
	public void setFuture(Future<?> future) {
		this.future = future;
	}

	/**
	 * Getter for the payload.
	 * @return the payload
	 */
	public Streamable getPayload() {
		return payload;
	}

	/**
	 * Getter for the sender.
	 * @return the sender
	 */
	public Address getOriginator() {
		return originator;
	}
}
