/*******************************************************************************
 * Copyright (c) 2009 Pafsanias Ftakas.
 *
 * This file is part of DistProc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * DistProc is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Eclipse Public License v1.0 for more details.
 *
 * Contributors:
 *     Pafsanias Ftakas - initial API and implementation
 *******************************************************************************/
package com.koutra.dist.proc.xml;

import java.io.IOException;
import java.util.List;

import org.xml.sax.ContentHandler;
import org.xml.sax.DTDHandler;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.SAXNotRecognizedException;
import org.xml.sax.SAXNotSupportedException;
import org.xml.sax.XMLReader;

import com.koutra.dist.proc.sax.SAXEvent;

public class SAXEventQueueReader implements XMLReader {
	private class DocumentLocator implements Locator {

		public int getColumnNumber() {
			return -1;
		}

		public int getLineNumber() {
			return -1;
		}

		public String getPublicId() {
			return null;
		}

		public String getSystemId() {
			return null;
		}
		
	}
	
	private ContentHandler contentHandler;
	private List<SAXEvent> eventQueue;
	
	public SAXEventQueueReader(List<SAXEvent> eventQueue) {
		this.eventQueue = eventQueue;
		this.contentHandler = null;
	}
	
	private void replayEvents() throws SAXException {
		for (SAXEvent event : eventQueue) {
			event.fireEvent(contentHandler);
		}
	}

	public void parse(InputSource input) throws IOException, SAXException {
		contentHandler.setDocumentLocator(new DocumentLocator());
		replayEvents();
	}

	public void parse(String systemId) throws IOException, SAXException {
		contentHandler.setDocumentLocator(new DocumentLocator());
		replayEvents();
	}

	public ContentHandler getContentHandler() {
		return contentHandler;
	}

	public void setContentHandler(ContentHandler handler) {
		contentHandler = handler;
	}

	//////////////////////////////////////////////////////////////////////////////////////
	// The rest of the implementation is not used.
	//////////////////////////////////////////////////////////////////////////////////////
	
	public DTDHandler getDTDHandler() {
		return null;
	}

	public EntityResolver getEntityResolver() {
		return null;
	}

	public ErrorHandler getErrorHandler() {
		return null;
	}

	public boolean getFeature(String name) throws SAXNotRecognizedException,
			SAXNotSupportedException {
		return false;
	}

	public Object getProperty(String name) throws SAXNotRecognizedException,
			SAXNotSupportedException {
		return null;
	}

	public void setDTDHandler(DTDHandler handler) {
	}

	public void setEntityResolver(EntityResolver resolver) {
	}

	public void setErrorHandler(ErrorHandler handler) {
	}

	public void setFeature(String name, boolean value)
			throws SAXNotRecognizedException, SAXNotSupportedException {
	}

	public void setProperty(String name, Object value)
			throws SAXNotRecognizedException, SAXNotSupportedException {
	}

}
